********************************************************************************
**	  FIGURE R2. EVENT STUDY ANALYSIS OF MINIMUM WAGES AND TEEN FERTILITY     **
** 								USING TWFE ESTIMATES 						  **
********************************************************************************

cap cd "/Users/rebecca.margolit/Dropbox/CHEPS/minwagefertility/replication"
cap cd "C:\Users\CHEPS Laptop 1\Dropbox (University of Oregon)\minwagefertility\replication"
global inputs "Data/"
global outputs "Output/"
 
*******************************     2003-2019     *************************************************

** load data 
use  ${inputs}fertilitymaster_2023_07_19_1995_2019.dta,  clear
keep if inrange(year, 2003,2019)
drop if quarter < 4 & year==2003

drop time 
sort st_fips year quarter
bys st_fips: gen time =_n
xtset st_fips time

** generate bump in minimum wage
by st_fips (time), sort: gen bump_q = lagmw_2019a - L1.lagmw_2019a
label var bump_q "Quarterly Minimum Wage Increase"

** create leads and lags
local first 12
local last 12
local v bump_q

forval f = `first'(-1)1 {
	sort st_fips time
	gen F`f' = F`f'.`v'
	label var  F`f' "-`f'"
	replace F`f' = 0 if F`f'==.
	if `f' ==`first' label var  F`f' "-`f'+"
}

forval l = 0/`last'  {
	gen L`l' = L`l'.`v'
	label var  L`l' "`l'"
	replace L`l' = 0 if L`l'==.
	if `l' ==`last' label var  L`l' "`l'+"
}

order F* L*
gsort st_fips -time
by st_fips: replace F`first' = sum(F`first')
gsort st_fips time
by st_fips: replace L`last' = sum(L`last')

replace F1 = 0

global controls "lagproportion_nhw_adolescents lagproportion_nhb_adolescents lagproportion_h_adolescents lagproportion_17_adolescents lagproportion_18_adolescents lagproportion_19_adolescents lagproportion_msa_adolescents lagmedicaidfamplan lagparental_involv lagcontraceptive_cov lagstateeitcrate lageitcrefund lagprimeageunempq lagrealwage_primeq laghpiq lagsexed lagmaxsnaptanf_2019 lagmandatory_wait lagdemgov lagfrachousedem lagfracsenatedem lagmedfund missingdemgov missingfrachouse missingfracsenate"
reghdfe adolescentbr F* L* $controls [w=femalepop], absorb(st_fips time) cl(st_fips)

estimates store A

local first 12
local xline = `first'+.5
coefplot ///
	(A, omitted  keep(F*  L*)  msize(small) recast(connected) lcolor(gs1) color(gs1) lwidth(thin) ciopts(recast(rcap)  lcolor(gs10) lwidth(thin))),  ///
	vertical xline(`xline') yline(0) graphregion(color(white)) yla(-1(0.5)1) yla(, nogrid) xlabel(1 "-12+" 5 "-8" 9 "-4" 13 "0" 17 "4" 21 "8" 25 "12+") ///
	ytitle("Estimated effect of MW increases") xtitle("Quarters since {it:t*}-3 (where {it:t*} = quarter of MW increase)") ///
	legend(off) nooffsets
graph export "${outputs}figure_r2.png", replace

