library(pacman)
p_load(tidyverse, did, data.table)


#### Get Data
data = fread("analysis/paperoutput/data_cs.csv") %>%
  mutate(st_fips = as.numeric(as.factor(st_fips)))

### Run CS Estimates: $1.00
{
att = att_gt(
  yname="adolescentbr",
  tname="time",
  idname="st_fips",
  gname="trtime_100",
  data=data,
  weightsname = "femalepop",
  xformla = ~small100,
  est_method = "dr", 
  control_group = "notyettreated", 
  bstrap = TRUE, 
  biters = 1000, 
  print_details = FALSE, 
  clustervars = "st_fips", 
  panel = TRUE
) 
agg_effects_es <- aggte(att, type = "dynamic", na.rm=TRUE)


#Create ylimit for scaling
xmin=-12
xmax=12
data_scale = as.data.frame(cbind(agg_effects_es$egt, agg_effects_es$att.egt, agg_effects_es$se.egt))
tval = agg_effects_es$crit.val.egt
tval = ifelse(is.na(tval), 2, tval)
data_scale = data_scale %>% filter(V1 >= xmin & V1 <=xmax) %>% mutate(min = V2 - tval*V3) %>% mutate(max = V2 + tval*V3) 
ymin = min(data_scale$min)
ymax = max(data_scale$max)

ymin=ifelse(ymin>=0, -1 * ymax/100, ymin)
ymax=ifelse(ymax <=0, -1*ymin/100, ymax)
ymin=ymin*1.25
ymax=ymax*1.25

#Edit Xscale 
if (min(agg_effects_es$egt) > xmin) {xmin = min(agg_effects_es$egt)}
if (max(agg_effects_es$egt) < xmax) {xmax = max(agg_effects_es$egt)}

# Plot event-study coefficients
plot <-  ggdid(agg_effects_es, xgap=3) + 
  theme_classic() +
  theme(legend.position = "none") + 
  geom_hline(yintercept =0, color="red") +
  geom_vline(xintercept =-0.5, color="red") +
  geom_line() +  geom_point(size=3.1) + 
  geom_errorbar(width=0.4, position=position_dodge(width=4), color="grey20") + 
  scale_x_continuous(limits=c(xmin-.3, xmax+.3,1), breaks = seq(xmin,xmax, by=4)) +
  ylim(ymin, ymax) +
  labs(title="", 
       col="",
       x=  expression(paste("Quarters since ", 
                              italic("t*"), 
                             "-3 (where ", 
                             italic("t*"), 
                             "= quarter of prominent MW increase)")),
       y= "Estimated effect of prominent MW increases"
  )  +
  theme(text=element_text(size=18))

ggsave(filename="Output/fig_r5b.png", plot, width=12, height=7)
}











### Run CS Estimates: $2.50 increases
{
att = att_gt(
  yname="adolescentbr",
  tname="time",
  idname="st_fips",
  gname="trtime_250",
  data=data,
  weightsname = "femalepop",
  xformla = ~small250,
  est_method = "dr", 
  control_group = "notyettreated", 
  bstrap = TRUE, 
  biters = 1000, 
  print_details = FALSE, 
  clustervars = "st_fips", 
  panel = TRUE
) 
agg_effects_es <- aggte(att, type = "dynamic", na.rm=TRUE)


#Create ylimit for scaling
xmin=-12
xmax=20
data_scale = as.data.frame(cbind(agg_effects_es$egt, agg_effects_es$att.egt, agg_effects_es$se.egt))
tval = agg_effects_es$crit.val.egt
tval = ifelse(is.na(tval), 2, tval)
data_scale = data_scale %>% filter(V1 >= xmin & V1 <=xmax) %>% mutate(min = V2 - tval*V3) %>% mutate(max = V2 + tval*V3) 
ymin = min(data_scale$min)
ymax = max(data_scale$max)

ymin=ifelse(ymin>=0, -1 * ymax/100, ymin)
ymax=ifelse(ymax <=0, -1*ymin/100, ymax)
ymin=ymin*1.25
ymax=ymax*1.25

#Edit Xscale 
if (min(agg_effects_es$egt) > xmin) {xmin = min(agg_effects_es$egt)}
if (max(agg_effects_es$egt) < xmax) {xmax = max(agg_effects_es$egt)}

# Plot event-study coefficients
plot <-  ggdid(agg_effects_es, xgap=3) + 
  theme_classic() +
  theme(legend.position = "none") + 
  geom_hline(yintercept =0,  color="red") +
  geom_vline(xintercept =-0.5,  color="red") +
  geom_line() +  geom_point(size=3.1) + 
  geom_errorbar(width=0.4, position=position_dodge(width=4), color="grey20") + 
  scale_x_continuous(limits=c(xmin-.3, xmax+.3,1), breaks = seq(xmin,xmax, by=4)) +
  ylim(ymin, ymax) +
  labs(title="", 
       col="",
       x=  expression(paste("Quarters since ", 
                            italic("t*"), 
                            "-3 (where ", 
                            italic("t*"), 
                            "= quarter of prominent MW increase)")),
       y= "Estimated effect of prominent MW increases"
  ) +
  theme(text=element_text(size=18))

ggsave(filename="Output/fig_r5d.png", plot, width=12, height=7)
}


