********************************************************************************
**	  FIGURE R6. EVENT STUDY ANALYSIS OF MINIMUM WAGES AND TEEN FERTILITY     **
** 								USING TWFE ESTIMATES 						  **
********************************************************************************

cap cd "/Users/rebecca.margolit/Dropbox/CHEPS/minwagefertility/replication"
cap cd "C:\Users\CHEPS Laptop 1\Dropbox (University of Oregon)\minwagefertility\replication"
global inputs "Data/"
global outputs "Output/"
 
global demographic "lagproportion_nhw_adolescents lagproportion_nhb_adolescents lagproportion_h_adolescents lagproportion_17_adolescents lagproportion_18_adolescents lagproportion_19_adolescents lagproportion_msa_adolescents"
global macrocontrols "lagmedicaidfamplan lagstateeitcrate lageitcrefund lagprimeageunempq lagrealwage_primeq laghpiq lagmaxsnaptanf_2019"
global sexcontrols "lagparental_involv lagcontraceptive_cov lagsexed lagmandatory_wait lagmedfund"
global political "lagdemgov lagfrachousedem lagfracsenatedem missingdemgov missingfrachouse missingfracsenate"

 
 
** define plotting program
 cap program drop plots
 program define plots

  local range yla(-1(0.25)1)
  		coefplot ///
  			(D, omitted keep(F*D L*D )  msize(small) recast(connected) lcolor(gs1) color(gs1) lwidth(thin) ciopts(recast(rcap)  lcolor(gs10) lwidth(thin))),  ///
  			vertical xline(12.5) yline(0) graphregion(color(white)) yla(-1(0.25)1, nogrid) ///
  		   `range' legend(off) nooffsets ///
			ytitle("Estimated effect of MW increases") xtitle("Quarters since {it:t*}-3 (where {it:t*} = quarter of MW increase)")

end


 cap program drop createleadlag
 program define createleadlag 
 args first last
 drop time 
sort st_fips year quarter
bys st_fips: gen time =_n
xtset st_fips time

** generate bump in minimum wage
	by st_fips (time), sort: gen bump_q = lagmw_2019a - L1.lagmw_2019a
	label var bump_q "Quarterly Minimum Wage Increase"

** create leads and lags
	local v bump_q

	forval f = `first'(-1)1 {
		sort st_fips time
		gen F`f' = F`f'.`v'
		label var  F`f' "-`f'"
		replace F`f' = 0 if F`f'==.
		if `f' ==`first' label var  F`f' "-`f'+"
	}

	forval l = 0/`last'  {
		gen L`l' = L`l'.`v'
		label var  L`l' "`l'"
		replace L`l' = 0 if L`l'==.
		if `l' ==`last' label var  L`l' "`l'+"
	}

	order F* L*
	gsort st_fips -time
	by st_fips: replace F`first' = sum(F`first')
	gsort st_fips time
	by st_fips: replace L`last' = sum(L`last')

replace F1 = 0
ren (F* L*) (F*_D L*_D)
end


use ${inputs}fertilitymaster_2023_07_19_1995_2019.dta, clear
sort st_fips year quarter
keep if inrange(year,2003,2014)
drop if year==2003 & quarter<4
createleadlag 12 12
reghdfe adolescentbr F* L* $controls [w=femalepop], absorb(st_fips time) cl(st_fips)
eststo D
plots
graph export "${outputs}figure_6a.png", replace

	
	
use ${inputs}fertilitymaster_2023_07_19_1995_2019.dta, clear
sort st_fips year quarter
keep if inrange(year,1995,2017)
createleadlag 12 12
reghdfe adolescentbr F* L* $controls [w=femalepop], absorb(st_fips time) cl(st_fips)
eststo D
plots
graph export "${outputs}figure_6b.png", replace


