********************************************************************************
*************** Clemens & Straint STYLE INCREASES DIFF & DIFFS *************
********************************************************************************

cap cd "/Users/rebecca.margolit/Dropbox/CHEPS/minwagefertility/replication"
cap cd "C:\Users\CHEPS Laptop 1\Dropbox (University of Oregon)\minwagefertility\replication"
global inputs "Data/"
global outputs "Output/"


global demographic "lagproportion_nhw_adolescents lagproportion_nhb_adolescents lagproportion_h_adolescents lagproportion_17_adolescents lagproportion_18_adolescents lagproportion_19_adolescents lagproportion_msa_adolescents"
global macrocontrols "lagmedicaidfamplan lagstateeitcrate lageitcrefund lagprimeageunempq lagrealwage_primeq laghpiq lagmaxsnaptanf_2019"
global sexcontrols "lagparental_involv lagcontraceptive_cov lagsexed lagmandatory_wait lagmedfund"
global political "lagdemgov lagfrachousedem lagfracsenatedem missingdemgov missingfrachouse missingfracsenate"
global smallmw "lagproportion_nhw_adolescents lagproportion_nhb_adolescents lagproportion_h_adolescents lagproportion_17_adolescents lagproportion_18_adolescents lagproportion_19_adolescents lagproportion_msa_adolescents lagmedicaidfamplan lagparental_involv lagcontraceptive_cov lagstateeitcrate lageitcrefund lagprimeageunempq lagrealwage_primeq laghpiq lagsexed lagmaxsnaptanf_2019 lagmandatory_wait lagdemgov lagfrachousedem lagfracsenatedem lagmedfund missingdemgov missingfrachouse missingfracsenate mw_small"


********************** 1. define stacking program ******************************


 cap program drop createstack
 program define createstack
 args smallcut smallcont minyear maxyear real
 /*smallcut = cutoff for smaller mw (i.e. 25 will drop all mw greater than 25 cents)
  smallcont = smaller mw to control  (i.e. 10 will create indicator for all mw increases)
  real="yes/no" to use real mw or not
  */

** Merge in federal mw 
 preserve
 use "${inputs}mw_new.dta" , clear
 ren statefips st_fips
 keep if inrange(year,`minyear',`maxyear')
 sort st_fips year quarter
 gen byte fed_mw = round(mean_fed_mw,.0001)==round(mw,.0001) 
 
 
 gen fedincrease = (mean_mw!=max_mw) & fed_mw==1 //min_fed_mw!=max_fed_mw captures federal increases, adding the condition that fed_mw==1 ensures that these increases must be binding.
 gen nonfedincrease = mean_mw!=max_mw & fed_mw==0
  * lag federal and nonfederal increases by 3-quarters
  sort st_fips year quarter
  foreach var of varlist fedincrease nonfedincrease mw {
	bysort st_fips: gen lag`var' = `var'[_n-3]
	replace lag`var' = `var' if lag`var'==.

} 

 tempfile fedmw
 save `fedmw'
 restore
 merge 1:1 st_fips year quarter using `fedmw'
keep if inrange(year,`minyear',`maxyear')

 cap drop time
 sort st_fips year quarter
 bys st_fips, sort: gen time=_n
 sort st_fips time
 xtset st_fips time
 
 /*Real Increases*/
if "`real'"=="yes" { 
	// Treatment Variable
	gen temp = lagmw_2019a if year==2019 & quarter==4
	by st_fips: egen mw_2019 = max(temp)
	by st_fips: gen mw_change_5year = lagmw_2019a[_n+20] - lagmw_2019a 
	replace mw_change_5year = mw_2019 - lagmw_2019a  if mw_change_5year==.
	
	// Indicator for whether the mw_increases began or not 
	by st_fips: gen mw_change =  lagmw_2019a - lagmw_2019a[_n-1] 
}
else {  
	// Treatment Variable
	gen temp = lagmw if year==2019 & quarter==4
	by st_fips: egen mw_2019 = max(temp)
	by st_fips: gen mw_change_5year = lagmw[_n+20] - lagmw 
	replace mw_change_5year = mw_2019  - lagmw  if mw_change_5year==.
	
	// Indicator for whether the mw_increases began or not 
	by st_fips:  gen mw_change =   lagmw  - lagmw[_n-1]
}
replace mw_change =0 if mw_change==.
 drop temp
 
 /*This will ensure all absorbing*/
  by st_fips: gen temp = time if mw_change_5year[_n-1]>=2.5 & mw_change>0  //treated time will be any large 20 quarter (5 year) increases >2.5
 * by st_fips: gen temp = time if mw_change_5year>=2.5 & mw_change_5year!=.  //treated time will be any large 20 quarter (5 year) increases >2.5

 by st_fips: egen trtime = min(temp)
 replace trtime = . if trtime!=temp
 sort trtime st_fips 
 gen eventid=_n if trtime!=.

 qui sum eventid 
 local max = r(max)
 di `max'
 gen trfips = .
 gen treatmenttime =.

/*========= TAKE 1: =========*/


 local eventno = "" 
 qui {
	 foreach i of numlist 1/`max' {
		preserve
		
		** Figure out Treatment State + Year-Quarter
		sum trtime if eventid==`i'
		global trtime = r(mean)
					
		sum st_fips if eventid==`i'
		global trfips = r(mean)
		
		
		***Sample Cuts
					
		//Keep donor states w/o "treatment" 
		tab time
		keep if inrange(time, $trtime - $lead, $trtime + $lag) 
		tab time
		
		* drop states w/ LARGE mw increases from the control group
		bys st_fips: egen max_5inc = max(mw_change_5year)
		drop if max_5inc >=2.5 & st_fips!=$trfips
		drop max_5inc
		
		* add a buffer
		gen droptag=1 if mw_change >= `smallcut'/100 & st_fips!=$trfips & mw_change>0
		gen placeholder = time if droptag==1
		by st_fips, sort: egen droptime=min(placeholder)
		
		//Balanced Panel -- Treatment State should be balanced. 
		bys st_fips: gen count=_N
		sum count if st_fips==$trfips
		local numobs= r(mean)
		replace trfips=$trfips
		replace treatmenttime=$trtime
		
		
		keep if count==`numobs'  
		by st_fips, sort: egen dropstate=min(droptag)
		drop if dropstate==1 & time>=droptime 
		
		//Create smaller mw control
		gen small_inc = time if mw_change>=`smallcont'/100 & mw_change>0 & st_fips!=$trfips 

		bys st_fips: egen small_year = min(small_inc) 
		gen byte mw_small = time>=small_year & st_fips!=$trfips
		
		//Keep only cases where there are control groups
		sum st_fips if st_fips!=$trfips
		local N =r(N) 
		gen order = _n
		by st_fips (order), sort: gen y = _n == 1 if st_fips!=$trfips
		replace y = sum(y)
		egen num_controls = max(y)
		drop order
		if `N' >0  {
			sort st_fips time
			replace mw_change=0
			replace mw_change=1 if st_fips==$trfips & trtime==$trtime
			forval f = $lead(-1)1 {
				gen F`f'_D = F`f'.mw_change
				label var  F`f'_D "-`f'"
				replace F`f'_D = 0 if F`f'.mw_change==.
				}
			forval l = 0/$lag  {
				gen L`l'_D = L`l'.mw_change
				label var  L`l'_D "`l'"
				replace L`l'_D = 0 if L`l'.mw_change==.
			}
			
			gen event=`i'
			gen treatment = st_fips==$trfips & time>=$trtime
			tempfile event`i'
			save `event`i'', replace
			local eventno = "`eventno'" + "`i' " 

		}
		else {
		
		}
		restore
	}

	clear
	foreach i of local eventno {
		append using `event`i''
		
	}
		
	}
	
	//KM: Moved this here...
	replace F1_D=0
	egen eventstate = group(event st_fips)
	egen eventtime = group(event time)
//	
** NEW 
/* cengiz_ssltt uses two additional fixed effects to eventstate and eventtime. He also uses eventorigcontrol and eventfedcontrol. What these mean is that they control for any additional increases (either federal or state increases) for the TREATED state within that event window. */
gen origcontrol=0
gen fedcontrol=0
by event trfips, sort: replace origcontrol = 1 if lagnonfedincrease==1 & time>treatmenttime & st_fips==trfips //origcontrol is equal to 1 if: a state had a nonfederal increase in a time period greater than the event treated time AND if it occurred in the treated state. 0 if any of thsoe are not met.
by event trfips, sort: replace fedcontrol = 1 if lagfedincrease==1 & time>treatmenttime //for the federal increases, we control for any state - even those in the control group
	egen eventorigcontrol = group(event origcontrol) //each event should have two values - 1 for pre and 1 for post treatment
	egen eventfedcontrol = group(event fedcontrol)
end
	
	
global lag=21
use ${inputs}fertilitymaster_2023_07_19_1995_2019.dta, clear
keep if inrange(year,2003,2019)
drop if year==2003 & quarter<4 //this is just how our data is
createstack 9999 0 2003 2019 "yes"

reghdfe adolescentbr treatment $smallmw [w=femalepop], absorb(eventstate eventtime) cl(eventstate)
estadd ysumm, mean
est save ${outputs}table_r3A_250, replace

reghdfe adolescentbr F*D treatment $smallmw [w=femalepop], absorb(eventstate eventtime c.eventtime##i.eventstate) cl(eventstate)
estadd ysumm, mean
est save ${outputs}table_r3B_250, replace

reghdfe adolescentbr  F*D L*D $smallmw [w=femalepop], absorb(eventstate eventtime c.eventtime##i.eventstate) cl(eventstate)
est save ${outputs}table_r3C_250, replace

