********************************************************************************
** 		TABLE 6. STACKED DD ESTIMATE OF PROMINENT MINIMUM WAGE INCREASES      **
**	 			($0.25 IN 2019$) AND TEEN ABORTION & PREGNANCY		`		  **
********************************************************************************


cap cd "/Users/rebecca.margolit/Dropbox/CHEPS/minwagefertility/replication"
cap cd "C:\Users\CHEPS Laptop 1\Dropbox (University of Oregon)\minwagefertility\replication"
global inputs "Data/"
global outputs "Output/"
 
 
********************** 1. define stacking program ******************************

 cap program drop createstack
 program define createstack
 args prominent smallcont treatfed //prominent = size of increase smallcut = smaller mw to cut, smallcont = smaller mw to control treatfed="yes/no" to incldue fed as part of identification


** Merge in federal mw 
 preserve
 use "${inputs}mw_new.dta" , clear
 ren statefips st_fips
 keep if inrange(year,2005,2017)
  collapse mean_fed_mw mean_mw max_mw mw mw_2019a, by(st_fips year)

 * create federal bumps - a federal bump is when the federal minimum wage increases
	* we can identify if there was a federal increase at any quarter when the "minimum" federal minimum wage doesn't equal the "max" federal minimum wage!
 sort st_fips year 
  gen byte fed_mw = round(mean_fed_mw,.0001)==round(mw,.0001) 
 
 
 gen fedincrease = (mean_mw!=max_mw) & fed_mw==1 //min_fed_mw!=max_fed_mw captures federal increases, adding the condition that fed_mw==1 ensures that these increases must be binding.
 gen nonfedincrease = mean_mw!=max_mw & fed_mw==0
  * lag federal and nonfederal increases by 3-quarters
  sort st_fips year 

 cap drop _merge
 tempfile fedmw
 save `fedmw'
 restore
 cap drop _merge
 merge 1:1 st_fips year  using `fedmw'
keep if inrange(year,2005,2017)

 cap drop time
 sort st_fips year
 bys st_fips, sort: gen time=_n
 sort st_fips time
 xtset st_fips time
 gen mw_change = d1.mw_2019a

 replace mw_change=0 if mw_change==.
 
  if "`treatfed'"=="yes" gen trtime = time if mw_change>=`prominent'/100  //treated time will be only be state
  else gen trtime = time if mw_change>=`prominent'/100 & fedincrease!=1 //treated time will be any increases
 sort trtime st_fips 
 gen eventid=_n if trtime!=.

 qui sum eventid 
 local max = r(max)
 di `max'
 gen trfips = .
 gen treatmenttime =.

/*========= TAKE 1: =========*/


 local eventno = "" 
 qui {
	 foreach i of numlist 1/`max' {
		preserve
		
		** Figure out Treatment State + Year-Quarter
		sum trtime if eventid==`i'
		global trtime = r(mean)
					
		sum st_fips if eventid==`i'
		global trfips = r(mean)
		
		
		***Sample Cuts
					
		//Keep donor states w/o "treatment" 
		tab time
		keep if inrange(time, $trtime - $lead, $trtime + $lag) 
		tab time
		
		* add a buffer
		* drop if mw_change >= `prominent'/100 & st_fips!=$trfips &  lagfedincrease!=1 //Do this so we drop any non-treated state mw increase	
		if `prominent'<= 25 gen droptag=1 if mw_change >= `prominent'/100 & st_fips!=$trfips //RM: creating a tag to indicate a state had an increase. 
		if `prominent'> 25 gen droptag=1 if mw_change >= `prominent'/200 & st_fips!=$trfips  //RM: creating a tag to indicate a state had an increase
		gen placeholder = time if droptag==1
			by st_fips, sort: egen droptime=min(placeholder)
		
		//Balanced Panel -- Treatment State should be balanced. 
		bys st_fips: gen count=_N
		sum count if st_fips==$trfips
		local numobs= r(mean)
		replace trfips=$trfips
		replace treatmenttime=$trtime
		
		
		keep if count==`numobs' 
		by st_fips, sort: egen dropstate=min(droptag)
		drop if dropstate==1 & time>=droptime 
		
		//Create smaller mw control
		gen small_inc = time if mw_change>=`smallcont'/100 & mw_change<`prominent'/100 & st_fips!=$trfips

		bys st_fips: egen small_year = min(small_inc) 
		gen byte mw_small = time>=small_year & st_fips!=$trfips
		
		//Keep only cases where there are control groups
		sum st_fips if st_fips!=$trfips
		local N =r(N) 
		gen order = _n
		by st_fips (order), sort: gen y = _n == 1 if st_fips!=$trfips
		replace y = sum(y)
		egen num_controls = max(y)
		drop order
		if `N' >0  {
			sort st_fips time
			replace mw_change=0
			replace mw_change=1 if st_fips==$trfips & trtime==$trtime
			forval f = $lead(-1)1 {
				gen F`f'_D = F`f'.mw_change
				label var  F`f'_D "-`f'"
				replace F`f'_D = 0 if F`f'.mw_change==.
				}
			forval l = 0/$lag  {
				gen L`l'_D = L`l'.mw_change
				label var  L`l'_D "`l'"
				replace L`l'_D = 0 if L`l'.mw_change==.
			}
			
			gen event=`i'
			gen treatment = st_fips==$trfips & time>=$trtime
			tempfile event`i'
			save `event`i'', replace
			local eventno = "`eventno'" + "`i' " 

		}
		else {
		
		}
		restore
	}

	clear
	foreach i of local eventno {
		append using `event`i''
		
	}
		
	}
	
	//KM: Moved this here...
	replace F1_D=0
	egen eventstate = group(event st_fips)
	egen eventtime = group(event time)
//	
** NEW 
/* cengiz_ssltt uses two additional fixed effects to eventstate and eventtime. He also uses eventorigcontrol and eventfedcontrol. What these mean is that they control for any additional increases (either federal or state increases) for the TREATED state within that event window. */
gen origcontrol=0
gen fedcontrol=0
by event trfips, sort: replace origcontrol = 1 if nonfedincrease==1 & time>treatmenttime & st_fips==trfips //origcontrol is equal to 1 if: a state had a nonfederal increase in a time period greater than the event treated time AND if it occurred in the treated state. 0 if any of thsoe are not met.
by event trfips, sort: replace fedcontrol = 1 if fedincrease==1 & time>treatmenttime //for the federal increases, we control for any state - even those in the control group
	egen eventorigcontrol = group(event origcontrol) //each event should have two values - 1 for pre and 1 for post treatment
	egen eventfedcontrol = group(event fedcontrol)

end

** define plotting program
 cap program drop plots
 program define plots

  local range yla(-1(0.25)1)
  		coefplot ///
  			(D, omitted keep(F*D L*D )  msize(small) recast(connected) lcolor(gs1) color(gs1) lwidth(thin) ciopts(recast(rcap)  lcolor(gs10) lwidth(thin))),  ///
  			vertical xline(12.5) yline(0) graphregion(color(white)) yla(-1(0.25)1, nogrid) ///
  		   `range' legend(off) nooffsets ///
  			ytitle("Estimated Effect of Prominent Minimum Wage") xtitle("Years Since Prominent Minimum Wage Increase")

end



**************************** Run Regressions: 2003-2019 **************************************
* re-specifying globals because I named them differently when I went back for the 1995-2019 dataset. Super annoying but I will go back and fix it later.
* controls
global demographic "lagproportion_nhw_adolescents lagproportion_nhb_adolescents lagproportion_h_adolescents lagproportion_17_adolescents lagproportion_18_adolescents lagproportion_19_adolescents lagproportion_msa_adolescents"
global macrocontrols "lagmedicaidfamplan lagstateeitcrate lageitcrefund lagprimeageunempq lagrealwage_primeq laghpiq lagmaxsnaptanf_2019"
global sexcontrols "lagparental_involv lagcontraceptive_cov lagsexed lagmandatory_wait lagmedfund"
global political "lagdemgov lagfrachousedem lagfracsenatedem missingdemgov missingfrachouse missingfracsenate"

global smallmw "lagproportion_nhw_adolescents lagproportion_nhb_adolescents lagproportion_h_adolescents lagproportion_17_adolescents lagproportion_18_adolescents lagproportion_19_adolescents lagproportion_msa_adolescents lagmedicaidfamplan lagparental_involv lagcontraceptive_cov lagstateeitcrate lageitcrefund lagprimeageunempq lagrealwage_primeq laghpiq lagsexed lagmaxsnaptanf_2019 lagmandatory_wait lagdemgov lagfrachousedem lagfracsenatedem lagmedfund missingdemgov missingfrachouse missingfracsenate mw_small"




 global lead=3
 global lag=3

 ** take pregnancy and abortion rates from guttmacher
 import excel "${inputs}cdcabortion_updated2023.04.05.xlsx", sheet("Sheet1") firstrow clear
 keep state year abortions 
 ren state statename
 drop if year == .
tempfile cdcabortions
save `cdcabortions'

** collapse our data to annual since outcomes are annual 
use ${inputs}fertilitymaster_2023_07_19_1995_2019.dta, clear
collapse (sum)adolescentbr  (mean) mw_2019a (mean)$demographic (mean)$macrocontrols (mean)$sexcontrols (mean)$political (mean)femalepop, by(st_fips statename year)
cap drop _merge 
merge m:1 statename year using `cdcabortions'
destring abortions, replace
drop if _merge ==1 //states that do not report to the CDC 
drop _merge

** create an abortion rate 
gen abortionrate1519 = (abortions/femalepop)*1000
gen pregnancyrate1519 = abortionrate1519 + adolescentbr

createstack 25 10 "no"


** regressions for table 4B
foreach var of varlist abortionrate1519 {
	reghdfe `var' F*D treatment mw_small $demographic $macrocontrols $sexcontrols $political [w=femalepop], absorb(eventstate eventtime c.eventtime##i.eventstate) cl(eventstate)
	estadd ysumm, mean
	est save ${outputs}table_r6a_`var', replace
	
	reghdfe `var' F*D L*D mw_small $demographic $macrocontrols $sexcontrols $political [w=femalepop], absorb(eventstate eventtime c.eventtime##i.eventstate) cl(eventstate)
	estadd ysumm, mean
	est save ${outputs}table_r6b_`var', replace
		
}

		


