*******************************************************************
**	  TABLE 7A.  ANALYSIS OF MINIMUM WAGES AND SEX ACTIVITY      **
** 					USING TWFE ESTIMATES 						 **
*******************************************************************


cap cd "/Users/rebecca.margolit/Dropbox/CHEPS/minwagefertility/replication"
cap cd "C:\Users\CHEPS Laptop 1\Dropbox (University of Oregon)\minwagefertility\replication"
global inputs "Data/"
global outputs "Output/"


******************************** 1. Get Data Reedy ************************************************

** load data 
use ${inputs}fertilitymaster_2023_07_19_1995_2019.dta, clear	

keep if quarter==1
keep if mod(year,2)==1 //Keep only YRBS Sample 
drop time 
sort st_fips year quarter
bys st_fips: gen time =_n
xtset st_fips time

** generate bump in minimum wage
by st_fips (time), sort: gen bump_q = mw_2019a - L1.mw_2019a
label var bump_q "Quarterly Minimum Wage Increase"

** create leads and lags
local first 3
local last 2
local v bump_q

forval f = `first'(-1)1 {
	sort st_fips time
	gen F`f' = F`f'.`v'
	label var  F`f' "-`f'"
	replace F`f' = 0 if F`f'==.
	if `f' ==`first' label var  F`f' "-`f'+"
}

forval l = 0/`last'  {
	gen L`l' = L`l'.`v'
	label var  L`l' "`l'"
	replace L`l' = 0 if L`l'==.
	if `l' ==`last' label var  L`l' "`l'+"
}

order F* L*
gsort st_fips -time
by st_fips: replace F`first' = sum(F`first')
gsort st_fips time
by st_fips: replace L`last' = sum(L`last')

replace F1 = 0


******************************** 2. Run Rregressions ************************************************
global controls "lagproportion_nhw_adolescents lagproportion_nhb_adolescents lagproportion_h_adolescents lagproportion_17_adolescents lagproportion_18_adolescents lagproportion_19_adolescents lagproportion_msa_adolescents lagmedicaidfamplan lagparental_involv lagcontraceptive_cov lagstateeitcrate lageitcrefund lagprimeageunempq lagrealwage_primeq laghpiq lagsexed lagmaxsnaptanf_2019 lagmandatory_wait lagdemgov lagfrachousedem lagfracsenatedem lagmedfund missingdemgov missingfrachouse missingfracsenate"
gen fips = st_fips
keep F* L* mw_2019a $controls fips year
merge 1:m fips year using  "${inputs}MW_RiskySex_2003_2019_Female1518_Combined_Master_2023.06.20.dta", keep(3) nogen

gen time = (year-2001)/2 + 1
foreach var of varlist sexually_active_3mo sex_partners_3p any_bc_3mo condom_use_3mo {

reghdfe `var' mw_2019a $controls [aw=weight_combined], cluster(fips) absorb(fips year race age_new grade_new sex)
est save "{$output}table_r7_`var'", replace
}




******************************** 3. Create Reg Tables ***********************************************
est sto clear
local i = 1
foreach var of varlist sexually_active_3mo sex_partners_3p any_bc_3mo condom_use_3mo {
sum `var' [aw=weight_combined]
local mean = r(mean)
est use "{$output}table_r7_`var'"
estadd scalar mean= `mean'
eststo a`i'
local i = `i'+1
}

esttab a* using "${outputs}table_r7.rtf", ///
replace label se star(* 0.10 ** 0.05 *** 0.01) keep(mw_2019a) ///
s(mean N, label("Mean of DV" "N"))
