*******************************************************************
**	  TABLE 7A.  ANALYSIS OF MINIMUM WAGES AND SEX ACTIVITY      **
** 						USING STACK DD	 						 **
*******************************************************************


cap cd "/Users/rebecca.margolit/Dropbox/CHEPS/minwagefertility/replication"
cap cd "C:\Users\CHEPS Laptop 1\Dropbox (University of Oregon)\minwagefertility\replication"
global inputs "Data/"
global outputs "Output/"
 
********************** 1. define stacking program ******************************

cap program drop createstack
 program define createstack
 args prominent smallcont minyear maxyear treatfed //prominent = size of increase smallcut = smaller mw to cut, smallcont = smaller mw to control treatfed="yes/no" to incldue fed as part of identification

** Merge in federal mw 
preserve
 use "${inputs2}mw_new.dta" , clear
 ren statefips st_fips
 keep if inrange(year,`minyear',`maxyear')
 * create federal bumps - a federal bump is when the federal minimum wage increases
	* we can identify if there was a federal increase at any quarter when the "minimum" federal minimum wage doesn't equal the "max" federal minimum wage!
 sort st_fips year quarter
  gen byte fed_mw = round(mean_fed_mw,.0001)==round(mw,.0001) 
 
 
 gen fedincrease = (mean_mw!=max_mw) & fed_mw==1 //min_fed_mw!=max_fed_mw captures federal increases, adding the condition that fed_mw==1 ensures that these increases must be binding.
 gen nonfedincrease = mean_mw!=max_mw & fed_mw==0
  * lag federal and nonfederal increases by 3-quarters
  sort st_fips year quarter
  foreach var of varlist fedincrease nonfedincrease {
	bysort st_fips: gen lag`var' = `var'[_n-3]
	replace lag`var' = `var' if lag`var'==.

} 
 tempfile fedmw
 save `fedmw'
 restore
 merge 1:1 st_fips year quarter using `fedmw'
keep if inrange(year,`minyear',`maxyear')
keep if mod(year,2)==1 //Keep only YRBS Sample 
keep if quarter==1
 
 cap drop time
 sort st_fips year quarter
 bys st_fips, sort: gen time=_n
 sort st_fips time
 xtset st_fips time
 gen mw_change = d1.mw_2019a

 replace mw_change=0 if mw_change==.
 
  if "`treatfed'"=="yes" gen trtime = time if mw_change>=`prominent'/100  //treated time will be only be state
  else gen trtime = time if mw_change>=`prominent'/100 & lagfedincrease!=1 //treated time will be any increases
 sort trtime st_fips 
 gen eventid=_n if trtime!=.

 qui sum eventid 
 local max = r(max)
 di `max'
 gen trfips = .
 gen treatmenttime =.

/*========= TAKE 1: =========*/


 local eventno = "" 
	 foreach i of numlist 1/`max' {
		dis `i'
		qui {
		preserve
		
		** Figure out Treatment State + Year-Quarter
		sum trtime if eventid==`i'
		global trtime = r(mean)
					
		sum st_fips if eventid==`i'
		global trfips = r(mean)
		
		
		***Sample Cuts
					
		//Keep donor states w/o "treatment" 
	tab time
		keep if inrange(time, $trtime - $lead, $trtime + $lag) 
		tab time
		
		* add a buffer
		* drop if mw_change >= `prominent'/100 & st_fips!=$trfips &  lagfedincrease!=1 //Do this so we drop any non-treated state mw increase	
		if `prominent'<= 25 gen droptag=1 if mw_change >= `prominent'/100 & st_fips!=$trfips //RM: creating a tag to indicate a state had an increase. 
		if `prominent'> 25 gen droptag=1 if mw_change >= `prominent'/200 & st_fips!=$trfips  //RM: creating a tag to indicate a state had an increase
		gen placeholder = time if droptag==1
			by st_fips, sort: egen droptime=min(placeholder)
		
		//Balanced Panel -- Treatment State should be balanced. 
		bys st_fips: gen count=_N
		sum count if st_fips==$trfips
		local numobs= r(mean)
		replace trfips=$trfips
		replace treatmenttime=$trtime
		
		
		keep if count==`numobs'  
		by st_fips, sort: egen dropstate=min(droptag)
		drop if dropstate==1 & time>=droptime 
		
		//Create smaller mw control
		gen small_inc = time if mw_change>=`smallcont'/100 & mw_change<`prominent'/100 & st_fips!=$trfips

		bys st_fips: egen small_year = min(small_inc) 
		gen byte mw_small = time>=small_year & st_fips!=$trfips
		
		//Keep only cases where there are control groups
		sum st_fips if st_fips!=$trfips
		local N =r(N) 
		gen order = _n
		by st_fips (order), sort: gen y = _n == 1 if st_fips!=$trfips
		replace y = sum(y)
		egen num_controls = max(y)
		drop order
		if `N' >0  {
			sort st_fips time
			replace mw_change=0
			replace mw_change=1 if st_fips==$trfips & trtime==$trtime
			forval f = $lead(-1)1 {
				gen F`f'_D = F`f'.mw_change
				label var  F`f'_D "-`f'"
				replace F`f'_D = 0 if F`f'.mw_change==.
				}
			forval l = 0/$lag  {
				gen L`l'_D = L`l'.mw_change
				label var  L`l'_D "`l'"
				replace L`l'_D = 0 if L`l'.mw_change==.
			}
			
			gen event=`i'
			gen treatment = st_fips==$trfips & time>=$trtime
			
			keep st_fips year time $controls mw_small  event treatment F*D L*D trfips
			gen fips= st_fips
			merge 1:m fips year using  "${inputs2}MW_RiskySex_2003_2019_Female1518_Combined_Master_2023.06.20.dta", keep(3) nogen
			drop if race==. | age_new==. | grade_new==. | sex==.
			
			tempfile event`i'
			save `event`i'', replace
			local eventno = "`eventno'" + "`i' " 

		}
		else {
		
		}
		restore
		}
	}

	clear
	foreach i of local eventno {
		append using `event`i''
		
	}
		
	
	//KM: Moved this here...
	replace F1_D=0
	*drop F2_D 
	*label var F1_D "-2to-1"
	egen eventstate = group(event fips)
	egen eventtime = group(event time)
//	
** NEW 
/* cengiz_ssltt uses two additional fixed effects to eventstate and eventtime. He also uses eventorigcontrol and eventfedcontrol. What these mean is that they control for any additional increases (either federal or state increases) for the TREATED state within that event window. */

end



**************************** 2. Run Regression **************************************
global controls "proportion_nhw_adolescents proportion_nhb_adolescents proportion_h_adolescents proportion_17_adolescents proportion_18_adolescents proportion_19_adolescents proportion_msa_adolescents medicaidfamplan parental_involv contraceptive_cov stateeitcrate eitcrefund primeageunempq realwage_primeq hpiq sexed maxsnaptanf_2019 mandatory_wait demgov frachousedem fracsenatedem medfund missingdemgov missingfrachouse missingfracsenate"
global lead=3
global lag=3
 
use ${inputs}fertilitymaster_2023_07_19_1995_2019.dta, clear
createstack 25 10 2003 2019 "no"
gen cond_sex_partners_3p = sex_partners_3p if sexually_active_3mo==1


eststo clear

foreach var of varlist sexually_active_3mo sex_partners_3p any_bc_3mo condom_use_3mo  {
reghdfe `var' F*D treatment $controls mw_small [aw=weight_combined], cluster(eventstate) absorb(eventstate eventtime race age_new grade_new sex national c.eventtime##i.eventstate)
est save "{$output}table_r7_`var'", replace 
}


******************************** 3. Create Reg Tables ***********************************************
est sto clear
local i = 1
foreach var of varlist sexually_active_3mo sex_partners_3p  cond_sex_partners_3p /*unprotected_sex_3mo1*/ any_bc_3mo condom_use_3mo {
sum `var' [aw=weight_combined]
local mean = r(mean)
est use "{$output}table_r7_`var'"
estadd scalar mean= `mean'
eststo a`i'
local i = `i'+1
}


esttab a* using "${outputs}table_r7.rtf", ///
append label se star(* 0.10 ** 0.05 *** 0.01) keep(treatment) ///
s(mean N, label("Mean of DV" "N"))


